<?php
/**
 * MagazineX functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package MagazineX
 * @since   1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( ! defined( 'MAGAZINEX_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'MAGAZINEX_VERSION', '1.0.5' );
}

if ( ! function_exists( 'magazinex_setup' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function magazinex_setup() {
		/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on MagazineX, use a find and replace
		* to change 'magazinex' to the name of your theme in all the template files.
		*/
		load_theme_textdomain( 'magazinex', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
		add_theme_support( 'title-tag' );

		// Enable support for Post Formats.
		add_theme_support(
			'post-formats',
			array(
				'aside',
				'image',
				'video',
				'quote',
				'link',
				'gallery',
				'chat',
				'audio',
				'status',
			)
		);

		/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
		add_theme_support( 'post-thumbnails' );

		// Register menus.
		register_nav_menus(
			array(
				'mzx-menu-primary' => esc_html__( 'Primary', 'magazinex' ),
				'mzx-menu-footer'  => esc_html__( 'Footer', 'magazinex' ),
			)
		);

		/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'width'       => 115,
				'height'      => 50,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);

		/**
		 * Gutenberg.
		 */
		// Add support for wide images.
		add_theme_support( 'align-wide' );

		// Editor Styles.
		add_theme_support( 'editor-styles' );
	}
endif;
add_action( 'after_setup_theme', 'magazinex_setup' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function magazinex_widgets_init() {
	$sidebars = apply_filters(
		'magazinex_sidebars_args',
		array(
			'mzx-right-sidebar'         => esc_html__( 'Right Sidebar', 'magazinex' ),
			'mzx-header-bar-1'          => esc_html__( 'Header Bar Column 1', 'magazinex' ),
			'mzx-header-bar-2'          => esc_html__( 'Header Bar Column 2', 'magazinex' ),
			'mzx-header-bar-3'          => esc_html__( 'Header Bar Column 3', 'magazinex' ),
			'mzx-drawer-sidebar'        => esc_html__( 'Drawer Sidebar', 'magazinex' ),
			'mzx-header-sidebar'        => esc_html__( 'Header Sidebar', 'magazinex' ),
			'mzx-header-action-sidebar' => esc_html__( 'Header Action Sidebar', 'magazinex' ),
			'mzx-footer-col-1'          => esc_html__( 'Footer Column 1', 'magazinex' ),
			'mzx-footer-col-2'          => esc_html__( 'Footer Column 2', 'magazinex' ),
			'mzx-footer-col-3'          => esc_html__( 'Footer Column 3', 'magazinex' ),
		)
	);

	foreach ( $sidebars as $id => $name ) {
		register_sidebar(
			apply_filters(
				'magazinex_sidebars_widget_args',
				array(
					'id'            => $id,
					'name'          => $name,
					'description'   => esc_html__( 'Add widgets here.', 'magazinex' ),
					'before_widget' => '<section id="%1$s" class="widget %2$s">',
					'after_widget'  => '</section>',
					'before_title'  => '<h2 class="widget-title">',
					'after_title'   => '</h2>',
				)
			)
		);
	}
}

add_action( 'widgets_init', 'magazinex_widgets_init' );

/**
 * Block Styles
 */
function magazinex_register_block_styles() {

	if ( function_exists( 'register_block_style' ) ) {

		register_block_style(
			'core/tag-cloud',
			array(
				'name'  => 'rounded',
				'label' => __( 'Rounded', 'magazinex' ),
			)
		);
	}
}

add_action( 'after_setup_theme', 'magazinex_register_block_styles' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function magazinex_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'magazinex_content_width', 640 );
}

add_action( 'after_setup_theme', 'magazinex_content_width', 0 );

/**
 * Enqueue scripts and styles.
 */
function magazinex_scripts() {
	$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_style( 'magazinex-style', get_stylesheet_uri(), array(), MAGAZINEX_VERSION );
	wp_style_add_data( 'magazinex-style', 'rtl', 'replace' );

	wp_enqueue_script( 'magazinex-navigation', get_template_directory_uri() . "/assets/js/navigation{$suffix}.js", array(), MAGAZINEX_VERSION, true );

	wp_enqueue_script( 'magazinex-js', get_template_directory_uri() . "/assets/js/magazinex{$suffix}.js", array(), MAGAZINEX_VERSION, true );

	wp_enqueue_script( 'magazinex-fitvids', get_template_directory_uri() . '/assets/js/jquery.fitvids' . $suffix . '.js', array( 'jquery' ), MAGAZINEX_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'magazinex_scripts' );

/**
 * Enqueue block editor styles.
 */
function magazinex_block_editor_styles() {
	wp_enqueue_style( 'magazinex-block-editor-styles', get_template_directory_uri() . '/block-editor-styles.css' );
}

add_action( 'enqueue_block_editor_assets', 'magazinex_block_editor_styles', 1, 1 );

/**
 * Utils methods.
 */
require get_template_directory() . '/inc/class-magazinex-utils.php';

/**
 * CSS Classes.
 */
require get_template_directory() . '/inc/class-magazinex-css-classes.php';

/**
 * Structure.
 */
require get_template_directory() . '/inc/hooks.php';
require get_template_directory() . '/inc/structure/header.php';
require get_template_directory() . '/inc/structure/content.php';
require get_template_directory() . '/inc/structure/footer.php';

/**
 * Breadcrumb trail file.
 */
require get_template_directory() . '/inc/class-magazinex-breadcrumb-trail.php';
require get_template_directory() . '/inc/class-magazinex-svg-icons.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Admin files.
 */

if ( is_admin() ) {
	require get_template_directory() . '/inc/admin/class-magazinex-admin.php';
	require get_template_directory() . '/inc/admin/class-magazinex-welcome-notice.php';
	require get_template_directory() . '/inc/admin/class-magazinex-dashboard.php';
	require get_template_directory() . '/inc/admin/class-magazinex-theme-review-notice.php';
}

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/class-magazinex-customizer.php';
require get_template_directory() . '/inc/class-magazinex-dynamic-css.php';

/**
 *  Option migration.
 */
require get_template_directory() . '/inc/class-magazinex-demo-import-migration.php';
require get_template_directory() . '/inc/class-magazinex-migration.php';

/**
 * Add meta boxes.
 */
require get_template_directory() . '/inc/meta-boxes/class-magazinex-meta-boxes.php';
require get_template_directory() . '/inc/meta-boxes/class-magazinex-meta-box-page-settings.php';

/**
 * Theme Constants.
 */
define( 'MAGAZINEX_PARENT_URL', get_template_directory_uri() );
define( 'MAGAZINEX_INCLUDES_URL', MAGAZINEX_PARENT_URL . '/inc' );
define( 'MAGAZINEX_ADMIN_URL', MAGAZINEX_INCLUDES_URL . '/admin' );
define( 'MAGAZINEX_ADMIN_IMAGES_URL', MAGAZINEX_PARENT_URL . '/assets/img' );
